# Command Line Inferface for ChatGPT

### Install 
```shell
pip install cligpt
```

### Usage
```shell
export OPENAI_API_KEY=[Your OpenAI API Key]

# launch
cligpt

# switch between roles
input `@role` then Enter

# exit
input `q` then Enter or input `exit` then Enter

# customize your roles
customize ~/.cligpt/config.json
```

### Uninstall
```shell
pip uninstall cligpt
(rm -rf ~/.cligpt)
```

